<?php
namespace Aheadworks\BlogGraphQl\Model\Resolver;

use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Aheadworks\Blog\Model\Config as BlogConfig;

/**
 * Class Config
 * @package Aheadworks\BlogGraphQl\Model\Resolver
 */
class Config implements ResolverInterface
{
    /**
     * @var BlogConfig
     */
    private $blogConfig;

    /**
     * @param BlogConfig $blogConfig
     */
    public function __construct(BlogConfig $blogConfig)
    {
        $this->blogConfig = $blogConfig;
    }

    /**
     * {@inheritdoc}
     */
    public function resolve(
        Field $field,
        $context,
        ResolveInfo $info,
        array $value = null,
        array $args = null
    ) {
        $storeId = isset($args['storeId']) ? $args['storeId'] : null;
        $config = [
            // general
            'enabled' => $this->blogConfig->isBlogEnabled($storeId),
            'route_to_blog' => $this->blogConfig->getRouteToBlog($storeId),
            'blog_title' => $this->blogConfig->getBlogTitle(),
            'posts_per_page' => $this->blogConfig->getNumPostsPerPage(),
            'display_sharing_buttons_at' => $this->blogConfig->getDisplaySharingAt(),
            'comments_enabled' => $this->blogConfig->isCommentsEnabled(),
            // sidebar
            'recent_posts' => $this->blogConfig->getNumRecentPosts(),
            'popular_tags' => $this->blogConfig->getNumPopularTags(),
            'highlight_popular_tags' => $this->blogConfig->isHighlightTags(),
            'cms_block' => $this->blogConfig->getSidebarCmsBlockId(),
            'category_listing_enabled' => $this->blogConfig->isDisplaySidebarCategoryListing($storeId),
            'category_listing_limit' => $this->blogConfig->getNumCategoriesToDisplay($storeId),
            // seo
            'meta_description' => $this->blogConfig->getBlogMetaDescription(),
            'url_type' => $this->blogConfig->getSeoUrlType($storeId),
            // related products
            'display_posts_on_product_page' => $this->blogConfig->isDisplayPostsOnProductPage($storeId),
            'block_position' => $this->blogConfig->getRelatedBlockPosition($storeId),
            'block_layout' => $this->blogConfig->getRelatedBlockLayout($storeId),
            'products_limit' => $this->blogConfig->getRelatedProductsLimit($storeId),
            'display_add_to_cart' => $this->blogConfig->isRelatedDisplayAddToCart($storeId)
        ];

        return $config;
    }
}
