<?php
declare(strict_types=1);
namespace Aheadworks\BlogGraphQl\Model\Resolver\DataProvider;

use Aheadworks\Blog\Api\Data\CategoryInterface;
use Magento\Framework\Api\SearchCriteriaInterface;
use Aheadworks\Blog\Api\CategoryRepositoryInterface;
use Magento\Framework\Reflection\DataObjectProcessor;

/**
 * Class Categories
 * @package Aheadworks\BlogGraphQl\Model\Resolver\DataProvider
 */
class Categories implements DataProviderInterface
{
    /**
     * @var CategoryRepositoryInterface
     */
    private $categoryRepository;

    /**
     * @var SearchResultFactory
     */
    private $searchResultFactory;

    /**
     * @var DataObjectProcessor
     */
    private $dataObjectProcessor;

    /**
     * @param CategoryRepositoryInterface $categoryRepository
     * @param SearchResultFactory $searchResultFactory
     * @param DataObjectProcessor $dataObjectProcessor
     */
    public function __construct(
        CategoryRepositoryInterface $categoryRepository,
        SearchResultFactory $searchResultFactory,
        DataObjectProcessor $dataObjectProcessor
    ) {
        $this->categoryRepository = $categoryRepository;
        $this->searchResultFactory = $searchResultFactory;
        $this->dataObjectProcessor = $dataObjectProcessor;
    }

    /**
     * {@inheritdoc}
     */
    public function getListData(SearchCriteriaInterface $searchCriteria, $storeId = null): SearchResult
    {
        $categoriesArray = [];
        $categories = $this->categoryRepository->getList($searchCriteria);
        foreach ($categories->getItems() as $category) {
            $categoriesArray[] = $this->dataObjectProcessor->buildOutputDataArray($category, CategoryInterface::class);
        }

        return $this->searchResultFactory->create($categories->getTotalCount(), $categoriesArray);
    }
}
