<?php
declare(strict_types=1);
namespace Aheadworks\BlogGraphQl\Model\Resolver\DataProvider;

use Aheadworks\Blog\Api\Data\PostInterface;
use Aheadworks\Blog\Api\PostRepositoryInterface;
use Magento\Framework\Api\SearchCriteriaInterface;
use Magento\Framework\Reflection\DataObjectProcessor;
use Magento\Widget\Model\Template\FilterEmulate;

/**
 * Class Posts
 * @package Aheadworks\BlogGraphQl\Model\Resolver\DataProvider
 */
class Posts implements DataProviderInterface
{
    /**
     * @var PostRepositoryInterface
     */
    private $postRepository;

    /**
     * @var SearchResultFactory
     */
    private $searchResultFactory;

    /**
     * @var DataObjectProcessor
     */
    private $dataObjectProcessor;

    /**
     * @var FilterEmulate
     */
    private $widgetFilter;

    /**
     * @param PostRepositoryInterface $postRepository
     * @param SearchResultFactory $searchResultFactory
     * @param DataObjectProcessor $dataObjectProcessor
     * @param FilterEmulate $widgetFilter
     */
    public function __construct(
        PostRepositoryInterface $postRepository,
        SearchResultFactory $searchResultFactory,
        DataObjectProcessor $dataObjectProcessor,
        FilterEmulate $widgetFilter
    ) {
        $this->postRepository = $postRepository;
        $this->searchResultFactory = $searchResultFactory;
        $this->dataObjectProcessor = $dataObjectProcessor;
        $this->widgetFilter = $widgetFilter;
    }

    /**
     * {@inheritdoc}
     */
    public function getListData(SearchCriteriaInterface $searchCriteria, $storeId = null): SearchResult
    {
        $postsArray = [];
        $posts = $this->postRepository->getList($searchCriteria);
        foreach ($posts->getItems() as $post) {
            $postArray = $this->dataObjectProcessor->buildOutputDataArray($post, PostInterface::class);

            $postArray[PostInterface::SHORT_CONTENT] = $this->widgetFilter->filter($post->getShortContent());
            $postArray[PostInterface::CONTENT] = $this->widgetFilter->filter($post->getContent());

            $postsArray[] = $postArray;
        }

        return $this->searchResultFactory->create($posts->getTotalCount(), $postsArray);
    }
}
