<?php
namespace Aheadworks\BlogGraphQl\Model\Resolver\DataProvider;

use Aheadworks\Blog\Api\Data\TagInterface;
use Aheadworks\Blog\Api\TagRepositoryInterface;
use Magento\Framework\Api\SearchCriteriaInterface;
use Magento\Framework\Reflection\DataObjectProcessor;

/**
 * Class Tags
 * @package Aheadworks\BlogGraphQl\Model\Resolver\DataProvider
 */
class Tags implements DataProviderInterface
{
    /**
     * @var TagRepositoryInterface
     */
    private $tagRepository;

    /**
     * @var SearchResultFactory
     */
    private $searchResultFactory;

    /**
     * @var DataObjectProcessor
     */
    private $dataObjectProcessor;

    /**
     * @param TagRepositoryInterface $tagRepository
     * @param SearchResultFactory $searchResultFactory
     * @param DataObjectProcessor $dataObjectProcessor
     */
    public function __construct(
        TagRepositoryInterface $tagRepository,
        SearchResultFactory $searchResultFactory,
        DataObjectProcessor $dataObjectProcessor
    ) {
        $this->tagRepository = $tagRepository;
        $this->searchResultFactory = $searchResultFactory;
        $this->dataObjectProcessor = $dataObjectProcessor;
    }

    /**
     * {@inheritdoc}
     */
    public function getListData(SearchCriteriaInterface $searchCriteria, $storeId = null): SearchResult
    {
        $tagsArray = [];
        $tags = $this->tagRepository->getList($searchCriteria);
        foreach ($tags->getItems() as $tag) {
            $tagsArray[] = $this->dataObjectProcessor->buildOutputDataArray($tag, TagInterface::class);
        }

        return $this->searchResultFactory->create($tags->getTotalCount(), $tagsArray);
    }
}
