<?php
namespace Aheadworks\BlogGraphQl\Model\Resolver;

use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Aheadworks\Blog\Api\PostRepositoryInterface;
use Aheadworks\Blog\Api\Data\PostInterface;
use Magento\Framework\Reflection\DataObjectProcessor;

/**
 * Class PostWithRelatedPosts
 * @package Aheadworks\BlogGraphQl\Model\Resolver
 */
class PostWithRelatedPosts implements ResolverInterface
{
    /**
     * @var PostRepositoryInterface
     */
    private $postRepository;

    /**
     * @var DataObjectProcessor
     */
    protected $dataObjectProcessor;

    /**
     * @param PostRepositoryInterface $postRepository
     * @param DataObjectProcessor $dataObjectProcessor
     */
    public function __construct(
        PostRepositoryInterface $postRepository,
        DataObjectProcessor $dataObjectProcessor
    ) {
        $this->postRepository = $postRepository;
        $this->dataObjectProcessor =$dataObjectProcessor;
    }

    /**
     * {@inheritdoc}
     */
    public function resolve(
        Field $field,
        $context,
        ResolveInfo $info,
        array $value = null,
        array $args = null
    ) {
        $storeId = isset($args['storeId']) ? $args['storeId'] : null;
        $postId = isset($args['postId']) ? $args['postId'] : null;
        $customerGroupId = isset($args['customerGroupId']) ? $args['customerGroupId'] : null;

        $result = [];
        if (!is_null($storeId) && !is_null($postId) && !is_null($customerGroupId)) {
            $post = $this->postRepository->getWithRelatedPosts($postId, $storeId, $customerGroupId);
            $result = $this->dataObjectProcessor->buildOutputDataArray($post, PostInterface::class);
        }

        return $result;
    }
}
